import click

debug_logging = False

all_colors = 'black', 'red', 'green', 'yellow', 'blue', 'magenta', \
             'cyan', 'white', 'bright_black', 'bright_red', \
             'bright_green', 'bright_yellow', 'bright_blue', \
             'bright_magenta', 'bright_cyan', 'bright_white'


def log_c(*argv):
    if len(argv) == 1:
        click.echo(click.style(argv[0], fg='magenta', bold=True))
    if len(argv) == 2:
        click.secho(argv[0], nl=False)
        click.echo(click.style(argv[1], fg='green', bold=True))


def log_r(str2):
    click.echo(click.style(str2, fg='red', bold=True))


def style(str):
    return click.style(str, fg='cyan', bold=True)


def log_cy(str):
    click.echo(click.style(str, fg='cyan', bold=True))


def log_cyb(str):
    click.echo(click.style(str, fg='cyan', bold=True, blink=True))


def log_g(str2):
    click.echo(click.style(str2, fg='green', bold=True))


def log_y(str2):
    click.echo(click.style(str2, fg='yellow', bold=True))


def log_bl(str2):
    click.echo(click.style(str2, fg='blue', bold=True))


# Colored logging
def debug(str):
    if debug_logging:
        click.secho((str))


# Colored logging
def debug_c(str):
    if debug_logging:
        click.echo(click.style(str, fg='blue', bold=True))


# Colored logging
def enable_debug():
    global debug_logging
    debug_logging = True


# Simple logging
def log(str):
    click.echo(click.style(str, fg='green', bold=True))


# blinking logging
def log_b(str):
    click.echo(click.style(str, blink=True))


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='human-name-compare',
    version='0.3.14',
    scripts=['hn-compare'],
    author="Robert Schoenthal",
    author_email="robert.schoenthal@gmail.com",
    description="a tool for comparing human names",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/digitalkaoz/py_human_name_compare",
    download_url="https://github.com/digitalkaoz/py_human_name_compare/archive/0.3.14.tar.gz",
    packages=['human_name_compare'],
    package_dir={'human_name_compare': 'human_name_compare'},
    keywords=['NLP', 'HUMANNAME'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
